import traceback

from cpl_core.configuration.configuration_model_abc import ConfigurationModelABC
from cpl_core.console import Console
from cpl_query.extension import List

from bot_data.model.level import Level


class DefaultLevelSettings(ConfigurationModelABC):

    def __init__(self):
        ConfigurationModelABC.__init__(self)

        self._levels = List(Level)
        self._level_header = ''

    @property
    def levels(self) -> List[Level]:
        return self._levels

    @property
    def level_header(self) -> str:
        return self._level_header

    def from_dict(self, settings: dict):
        try:
            self._level_header = settings['LevelHeader']
            for level in settings['Levels']:
                self._levels.append(Level(
                    level['Name'],
                    level['Color'],
                    int(level['MinXp']),
                    int(level['Permissions']),
                    None
                ))
        except Exception as e:
            Console.error(f'[ ERROR ] [ {__name__} ]: Reading error in {type(self).__name__} settings')
            Console.error(f'[ EXCEPTION ] [ {__name__} ]: {e} -> {traceback.format_exc()}')
